@@ -36,15 +36,15 @@ class PVRGCodec : public ImageCodec
 {
 public:
   PVRGCodec();
-  ~PVRGCodec();
-  bool CanDecode(TransferSyntax const &ts) const;
-  bool CanCode(TransferSyntax const &ts) const;
+  ~PVRGCodec() override;
+  bool CanDecode(TransferSyntax const &ts) const override;
+  bool CanCode(TransferSyntax const &ts) const override;
 
-  bool Decode(DataElement const &is, DataElement &os);
-  bool Code(DataElement const &in, DataElement &out);
+  bool Decode(DataElement const &is, DataElement &os) override;
+  bool Code(DataElement const &in, DataElement &out) override;
   void SetLossyFlag( bool l );
 
-  virtual ImageCodec * Clone() const;
+  ImageCodec * Clone() const override;
 private:
 };
 
